pub fn parse_level_filter_str(s: &str) -> Result<LevelFilter>Expand description
Parses a string into a LevelFilter.
Errors
Returns an error if the provided string is not a valid LevelFilter.
pub fn parse_level_filter_str(s: &str) -> Result<LevelFilter>Parses a string into a LevelFilter.
Returns an error if the provided string is not a valid LevelFilter.